@@ -7,10 +7,10 @@ use FFI::Platypus;
 use base qw( Exporter );
 use constant 1.32 ();
 
-our @EXPORT = qw( record_layout );
+our @EXPORT = qw( record_layout record_layout_1 );
 
 # ABSTRACT: FFI support for structured records data
-our $VERSION = '0.97_02'; # TRIAL VERSION
+our $VERSION = '0.97_03'; # TRIAL VERSION
 
 
 sub record_layout
@@ -159,6 +159,35 @@ sub record_layout
   ();
 }
 
+
+# TODO: maybe we should invert this so that record_layout calls record_layout_1
+
+sub record_layout_1
+{
+  if(@_ % 2 == 0)
+  {
+    $DB::single = 1;
+    my $ffi = FFI::Platypus->new( api => 1 );
+    unshift @_, $ffi;
+    goto &record_layout;
+  }
+  elsif(defined $_[0] && ref($_[0]) eq 'ARRAY')
+  {
+    my @args = @{ shift @_ };
+    unshift @args, api => 1;
+    unshift @_, \@args;
+    goto &record_layout;
+  }
+  elsif(defined $_[0] && eval { $_[0]->isa('FFI::Platypus') })
+  {
+    goto &record_layout;
+  }
+  else
+  {
+    croak "odd number of arguments, but first argument is not either an array reference or Platypus instance";
+  }
+}
+
 1;
 
 __END__
@@ -173,7 +202,7 @@ FFI::Platypus::Record - FFI support for structured records data
 
 =head1 VERSION
 
-version 0.97_02
+version 0.97_03
 
 =head1 SYNOPSIS
 
@@ -378,6 +407,15 @@ Arrays of integer, floating points and opaque pointers are supported.
  $foo->bar(5, -6); # sets the 5th element in the array to -6
  my $item = $foo->bar(5); gets the 5th element in the array
 
+=head2 record_layout_1
+
+ record_layout_1($ffi, $type => $name, ... );
+ record_layout_1(\@ffi_args, $type => $name, ... );
+ record_layout_1($type => $name, ... );
+
+This function works like C<record_layout> except that
+C<api =E<gt> 1> is used instead of the legacy API.
+
 =head1 TODO
 
 These useful features (and probably more) are missing:
